/************************************************************************
 *
 * Copyright (C) 2020-2024 IRCAD France
 * Copyright (C) 2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <sight/viz/qt3d/config.hpp>

#include <core/factory_registry.hpp>
#include <core/macros.hpp>

#include <string>

namespace sight::viz::qt3d
{

class window_interactor;

namespace registry
{

using key_t = std::string;
using type  = sight::core::factory_registry<std::shared_ptr<sight::viz::qt3d::window_interactor>(), key_t>;

SIGHT_VIZ_QT3D_API SPTR(type) get();

} // namespace registry.

} // namespace sight::viz::qt3d.
